@@ -31,7 +31,6 @@ GENERATOR_OPTS = [
 
 RULE_OPTS = [
     cfg.MultiStrOpt('namespace',
-                    required=True,
                     help='Option namespace(s) under "oslo.policy.policies" in '
                          'which to query for options.'),
     cfg.StrOpt('format',
@@ -42,7 +41,6 @@ RULE_OPTS = [
 
 ENFORCER_OPTS = [
     cfg.StrOpt('namespace',
-               required=True,
                help='Option namespace under "oslo.policy.enforcer" in '
                     'which to look for a policy.Enforcer.'),
 ]
@@ -279,6 +277,9 @@ def _generate_sample(namespaces, output_file=None, output_format='yaml',
             ',\n    '.join(sections_text),
             '\n}\n'))
 
+    if output_file != sys.stdout:
+        output_file.close()
+
 
 def _generate_policy(namespace, output_file=None):
     """Generate a policy file showing what will be used.
@@ -306,6 +307,9 @@ def _generate_policy(namespace, output_file=None):
     for section in _sort_and_format_by_section(policies, include_help=False):
         output_file.write(section)
 
+    if output_file != sys.stdout:
+        output_file.close()
+
 
 def _list_redundant(namespace):
     """Generate a list of configured policies which match defaults.
@@ -334,21 +338,36 @@ def on_load_failure_callback(*args, **kwargs):
     raise
 
 
-def generate_sample(args=None):
+def _check_for_namespace_opt(conf):
+    # NOTE(bnemec): This opt is required, but due to lp#1849518 we need to
+    # make it optional while our consumers migrate to the new method of
+    # parsing cli args. Making the arg itself optional and explicitly checking
+    # for it in the tools will allow us to migrate projects without breaking
+    # anything. Once everyone has migrated, we can make the arg required again
+    # and remove this check.
+    if conf.namespace is None:
+        raise cfg.RequiredOptError('namespace', 'DEFAULT')
+
+
+def generate_sample(args=None, conf=None):
     logging.basicConfig(level=logging.WARN)
-    conf = cfg.ConfigOpts()
+    # Allow the caller to pass in a local conf object for unit testing
+    if conf is None:
+        conf = cfg.CONF
     conf.register_cli_opts(GENERATOR_OPTS + RULE_OPTS)
     conf.register_opts(GENERATOR_OPTS + RULE_OPTS)
     conf(args)
+    _check_for_namespace_opt(conf)
     _generate_sample(conf.namespace, conf.output_file, conf.format)
 
 
 def generate_policy(args=None):
     logging.basicConfig(level=logging.WARN)
-    conf = cfg.ConfigOpts()
+    conf = cfg.CONF
     conf.register_cli_opts(GENERATOR_OPTS + ENFORCER_OPTS)
     conf.register_opts(GENERATOR_OPTS + ENFORCER_OPTS)
     conf(args)
+    _check_for_namespace_opt(conf)
     _generate_policy(conf.namespace, conf.output_file)
 
 
@@ -367,12 +386,15 @@ def _upgrade_policies(policies, default_policies):
                           'new_name': rule_default.name})
 
 
-def upgrade_policy(args=None):
+def upgrade_policy(args=None, conf=None):
     logging.basicConfig(level=logging.WARN)
-    conf = cfg.ConfigOpts()
+    # Allow the caller to pass in a local conf object for unit testing
+    if conf is None:
+        conf = cfg.CONF
     conf.register_cli_opts(GENERATOR_OPTS + RULE_OPTS + UPGRADE_OPTS)
     conf.register_opts(GENERATOR_OPTS + RULE_OPTS + UPGRADE_OPTS)
     conf(args)
+    _check_for_namespace_opt(conf)
     with open(conf.policy, 'r') as input_data:
         policies = policy.parse_file_contents(input_data.read())
     default_policies = get_policies_dict(conf.namespace)
@@ -380,12 +402,11 @@ def upgrade_policy(args=None):
     _upgrade_policies(policies, default_policies)
 
     if conf.output_file:
-        if conf.format == 'yaml':
-            yaml.safe_dump(policies, open(conf.output_file, 'w'),
-                           default_flow_style=False)
-        elif conf.format == 'json':
-            jsonutils.dump(policies, open(conf.output_file, 'w'),
-                           indent=4)
+        with open(conf.output_file, 'w') as fh:
+            if conf.format == 'yaml':
+                yaml.safe_dump(policies, fh, default_flow_style=False)
+            elif conf.format == 'json':
+                jsonutils.dump(policies, fh, indent=4)
     else:
         if conf.format == 'yaml':
             sys.stdout.write(yaml.safe_dump(policies,
@@ -396,8 +417,9 @@ def upgrade_policy(args=None):
 
 def list_redundant(args=None):
     logging.basicConfig(level=logging.WARN)
-    conf = cfg.ConfigOpts()
+    conf = cfg.CONF
     conf.register_cli_opts(ENFORCER_OPTS)
     conf.register_opts(ENFORCER_OPTS)
     conf(args)
+    _check_for_namespace_opt(conf)
     _list_redundant(conf.namespace)
