@@ -17,15 +17,20 @@
 
 import os
 
+from oslo_config import cfg
+from sphinx.util import logging
+
 from oslo_policy import generator
 
+LOG = logging.getLogger(__name__)
+
 
 def generate_sample(app):
     """Generate a sample policy file."""
 
     if not app.config.policy_generator_config_file:
-        app.warn("No policy_generator_config_file is specified, "
-                 "skipping sample policy generation")
+        LOG.warning("No policy_generator_config_file is specified, "
+                    "skipping sample policy generation")
         return
 
     if isinstance(app.config.policy_generator_config_file, list):
@@ -46,7 +51,7 @@ def _get_default_basename(config_file):
 def _generate_sample(app, policy_file, base_name):
 
     def info(msg):
-        app.info('[%s] %s' % (__name__, msg))
+        LOG.info('[%s] %s' % (__name__, msg))
 
     # If we are given a file that isn't an absolute path, look for it
     # in the source directory if it doesn't exist.
@@ -73,8 +78,14 @@ def _generate_sample(app, policy_file, base_name):
         out_file = os.path.join(app.srcdir, file_name)
 
     info('writing sample policy to %s' % out_file)
+    # NOTE(bnemec): We don't want to do cli parsing on the global object here
+    # because that can break consumers who do cli arg registration on import
+    # in their documented modules. It's not allowed to register a cli arg after
+    # the args have been parsed once.
+    conf = cfg.ConfigOpts()
     generator.generate_sample(args=['--config-file', config_path,
-                                    '--output-file', out_file])
+                                    '--output-file', out_file],
+                              conf=conf)
 
 
 def setup(app):
