@@ -10,9 +10,9 @@
 #    under the License.
 
 import operator
+from unittest import mock
 import warnings
 
-import mock
 from oslo_config import cfg
 import stevedore
 import testtools
@@ -500,8 +500,9 @@ class GeneratorRaiseErrorTestCase(testtools.TestCase):
     def test_generator_call_with_no_arguments_raises_error(self):
         testargs = ['oslopolicy-sample-generator']
         with mock.patch('sys.argv', testargs):
+            local_conf = cfg.ConfigOpts()
             self.assertRaises(cfg.RequiredOptError, generator.generate_sample,
-                              [])
+                              [], local_conf)
 
 
 class GeneratePolicyTestCase(base.PolicyBaseTestCase):
@@ -594,7 +595,7 @@ class ListRedundantTestCase(base.PolicyBaseTestCase):
                                deprecated_rule=deprecated_rule,
                                deprecated_reason='reason',
                                deprecated_since='T')
-            )
+        )
 
         # Mock out stevedore to return the configured enforcer
         ext = stevedore.extension.Extension(name='testing', entry_point=None,
@@ -655,6 +656,8 @@ class UpgradePolicyTestCase(base.PolicyBaseTestCase):
                                             plugin=None,
                                             obj=[self.new_policy])
         self.extensions.append(ext)
+        # Just used for cli opt parsing
+        self.local_conf = cfg.ConfigOpts()
 
     def test_upgrade_policy_json_file(self):
         test_mgr = stevedore.named.NamedExtensionManager.make_test_instance(
@@ -669,9 +672,10 @@ class UpgradePolicyTestCase(base.PolicyBaseTestCase):
                         self.get_config_file_fullname('new_policy.json'),
                         '--format', 'json']
             with mock.patch('sys.argv', testargs):
-                generator.upgrade_policy()
+                generator.upgrade_policy(conf=self.local_conf)
                 new_file = self.get_config_file_fullname('new_policy.json')
-                new_policy = jsonutils.loads(open(new_file, 'r').read())
+                with open(new_file, 'r') as fh:
+                    new_policy = jsonutils.loads(fh.read())
                 self.assertIsNotNone(new_policy.get('new_policy_name'))
                 self.assertIsNone(new_policy.get('deprecated_name'))
 
@@ -688,9 +692,10 @@ class UpgradePolicyTestCase(base.PolicyBaseTestCase):
                         self.get_config_file_fullname('new_policy.yaml'),
                         '--format', 'yaml']
             with mock.patch('sys.argv', testargs):
-                generator.upgrade_policy()
+                generator.upgrade_policy(conf=self.local_conf)
                 new_file = self.get_config_file_fullname('new_policy.yaml')
-                new_policy = yaml.safe_load(open(new_file, 'r'))
+                with open(new_file, 'r') as fh:
+                    new_policy = yaml.safe_load(fh)
                 self.assertIsNotNone(new_policy.get('new_policy_name'))
                 self.assertIsNone(new_policy.get('deprecated_name'))
 
@@ -706,7 +711,7 @@ class UpgradePolicyTestCase(base.PolicyBaseTestCase):
                         '--namespace', 'test_upgrade',
                         '--format', 'json']
             with mock.patch('sys.argv', testargs):
-                generator.upgrade_policy()
+                generator.upgrade_policy(conf=self.local_conf)
                 expected = '''{
     "new_policy_name": "rule:admin"
 }'''
@@ -724,7 +729,7 @@ class UpgradePolicyTestCase(base.PolicyBaseTestCase):
                         '--namespace', 'test_upgrade',
                         '--format', 'yaml']
             with mock.patch('sys.argv', testargs):
-                generator.upgrade_policy()
+                generator.upgrade_policy(conf=self.local_conf)
                 expected = '''new_policy_name: rule:admin
 '''
                 self.assertEqual(expected, stdout.getvalue())
